DimensionGroup class

A logical grouping of Performance Insights metrics for a related subject area. For example, the db.sql dimension group consists of the following dimensions: db.sql.id, db.sql.db_id, db.sql.statement, and db.sql.tokenized_id.

Constructors

DimensionGroup({required String group, List<String>? dimensions, int? limit})

Properties

dimensions → List<String>?
A list of specific dimensions from a dimension group. If this parameter is not present, then it signifies that all of the dimensions in the group were requested, or are present in the response.
final
group → String
The name of the dimension group. Valid values are:
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int?
The maximum number of items to fetch for this dimension group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited